# Phaedo - Python Domain Model Library

## About

Phaedo is a Python library helping developpers to create structured data object with typing, validating, and processing features. This library is inspired from DDD (Domain Driven Development), especially from the concept of "Domain Model". Developpers will find this helpful to make and keep codes easily and cleanly.

## Quickstart Guide

[WIP]